package envoy.client.util;

/**
 * Provides methods to handle outgoing issues.
 *
 * @author Leon Hofmeister
 * @author Kai S. K. Engelbart
 * @since Envoy Client v0.2-beta
 */
public final class IssueUtil {

	private IssueUtil() {}

	/**
	 * Normalizes line breaks and appends the user name to the issue description if
	 * requested.
	 *
	 * @param description the description to sanitize
	 * @param username    the user who submitted the issue. Should be
	 *                    {@code null} if he does not want to be named.
	 * @return the sanitized description
	 * @since Envoy Client v0.2-beta
	 */
	public static String sanitizeIssueDescription(String description, String username) {

		// Trim and replace line breaks by <br> tags
		description = description.trim().replaceAll(System.getProperty("line.separator"), "<br>");

		// Append user name if requested
		if (username != null)
			description += String.format("<br>Submitted by user %s.", username);

		return description;
	}
}
